@@ -15,8 +15,6 @@ hostname, or hostname:port combination. If no variable is set, it defaults
 to http://localhost:8080/
 """
 
-from __future__ import (absolute_import, division, print_function, unicode_literals)
-
 import sys, os
 from eigeningenuity.util import _do_eigen_json_request, EigenException, RemoteServerException, serverTimeToPythonTime
 
@@ -81,7 +79,7 @@ class EigenServer (object):
            appurl = apps[appname]['url']
            if appurl.startswith('/'):
               appurl = appurl[1:]
-
+           print(self.__baseurl + appurl)
            return self.__baseurl + appurl
         else:
            return None
